QrtrClientConnectionRequest

Enum QrtrClientConnectionRequest 

pub enum QrtrClientConnectionRequest {
    Read {
        responder: QrtrClientConnectionReadResponder,
    },
    Write {
        dst_node_id: u32,
        dst_port: u32,
        data: Vec<u8>,
        responder: QrtrClientConnectionWriteResponder,
    },
    GetSignals {
        responder: QrtrClientConnectionGetSignalsResponder,
    },
    GetPortId {
        responder: QrtrClientConnectionGetPortIdResponder,
    },
    GetNodeId {
        responder: QrtrClientConnectionGetNodeIdResponder,
    },
    CloseConnection {
        responder: QrtrClientConnectionCloseConnectionResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: QrtrClientConnectionControlHandle, method_type: MethodType, }, }
The connection used between a QRTR client and the QRTR driver.

Variants



Read

Reads a QRTR frame via the connection.

Only one read request can be performed at a time.

  • src_node_id: Source node ID of the QRTR frame.
  • src_port: Source port of the QRTR frame.
  • data: QRTR payload.
  • Errors:
    • WOULD_BLOCK: Cannot read; should wait in non-blocking mode.
    • ALREADY_PENDING: More than one read operation is pending in blocking mode.
    • INTERNAL_ERROR: Unexpected QRTR error.


Write

Writes a QRTR frame.

Only one write request can be performed at a time.

  • Errors:
    • WOULD_BLOCK: Cannot write; should wait in non-blocking mode.
    • ALREADY_PENDING: More than one write operation is pending in blocking mode.
    • REMOTE_NODE_UNAVAILABLE: Target node unavailable.
    • INTERNAL_ERROR: Unexpected QRTR error.

Fields

dst_node_id: u32
dst_port: u32
data: Vec<u8>


GetSignals

Retrieves the signals eventpair.

  • response signals an eventpair that is signalled with SIGNAL_READABLE and SIGNAL_WRITABLE when read and write buffers are available, respectively.


GetPortId

Retrieves the port id.



GetNodeId

Retrieves the node id of AP.



CloseConnection

Close the connection.

Server end drops its end of the channel after replying. This can be used for synchronous resource release.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations