pub enum QrtrConnectorRequest {
GetConnection {
options: ConnectionOptions,
proxy: ServerEnd<QrtrClientConnectionMarker>,
responder: QrtrConnectorGetConnectionResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: QrtrConnectorControlHandle,
method_type: MethodType,
},
}Expand description
Vends client connections with no access constraints in QRTR.
Variants
GetConnection
Gets a new connection from QRTR.
If port is specificed in options, creates a connection with target
port. Otherwise, assigns a random port for the connection.
- Errors:
INTERNAL_ERROR: Unexpected QRTR error.INVALID_ARGS: Invalid arguments inConnectionOptions.NO_RESOURCES: No non-reserved port available.ALREADY_BOUND: Specified port inConnectionOptionsis in use.
Fields

options: ConnectionOptions
proxy: ServerEnd<QrtrClientConnectionMarker>
responder: QrtrConnectorGetConnectionResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: QrtrConnectorControlHandle
method_type: MethodTypeImplementations
Sourceimpl QrtrConnectorRequest
impl QrtrConnectorRequest
pub fn into_get_connection( self, ) -> Option<(ConnectionOptions, ServerEnd<QrtrClientConnectionMarker>, QrtrConnectorGetConnectionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL