pub enum QrtrTransportChannelRequest {
Read {
responder: QrtrTransportChannelReadResponder,
},
Write {
data: Vec<u8>,
responder: QrtrTransportChannelWriteResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: QrtrTransportChannelControlHandle,
method_type: MethodType,
},
}Expand description
The channel for a transport driver that communicates with the remote processor and the QRTR driver.
Every message is preambled by a QRTR header, consult the appropriate specification for format.
Variants
Read
Reads a QRTR frame from a transport driver.
Blocks until an inbound frame is ready to be consumed. Only one read request can be performed at a time.
data: QRTR frame.
- Errors:
ALREADY_PENDING: More than one read operation is pending.INTERNAL_ERROR: Unexpected QRTR error.
Fields

responder: QrtrTransportChannelReadResponderWrite
Writes a QRTR frame to a transport driver.
Only one write request can be performed at a time.
- Errors:
ALREADY_PENDING: More than one write operation is pending.INTERNAL_ERROR: Unexpected QRTR error.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: QrtrTransportChannelControlHandle
method_type: MethodTypeImplementations
Sourceimpl QrtrTransportChannelRequest
impl QrtrTransportChannelRequest
pub fn into_read(self) -> Option<QrtrTransportChannelReadResponder>
pub fn into_write(self) -> Option<(Vec<u8>, QrtrTransportChannelWriteResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL