pub enum QrtrTransportConnectorRequest {
EstablishConnection {
options: TransportConnectionOptions,
proxy: ClientEnd<QrtrTransportChannelMarker>,
responder: QrtrTransportConnectorEstablishConnectionResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: QrtrTransportConnectorControlHandle,
method_type: MethodType,
},
}Expand description
Used by a transport driver that communicates with a remote processor to establish a new channel to the QRTR driver.
Variants
EstablishConnection
Establishes a channel.
Child drivers should only establish one connection to the QRTR driver.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: QrtrTransportConnectorControlHandle
method_type: MethodTypeImplementations
Sourceimpl QrtrTransportConnectorRequest
impl QrtrTransportConnectorRequest
pub fn into_establish_connection( self, ) -> Option<(TransportConnectionOptions, ClientEnd<QrtrTransportChannelMarker>, QrtrTransportConnectorEstablishConnectionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL