#[repr(C)]pub struct QrtrClientConnectionGetPortIdResponse {
pub port_id: u32,
}Fields
port_id: u32Trait Implementations
Sourceimpl Clone for QrtrClientConnectionGetPortIdResponse
impl Clone for QrtrClientConnectionGetPortIdResponse
Sourcefn clone(&self) -> QrtrClientConnectionGetPortIdResponse
fn clone(&self) -> QrtrClientConnectionGetPortIdResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<QrtrClientConnectionGetPortIdResponse, D> for QrtrClientConnectionGetPortIdResponsewhere
D: ResourceDialect,
impl<D> Decode<QrtrClientConnectionGetPortIdResponse, D> for QrtrClientConnectionGetPortIdResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> QrtrClientConnectionGetPortIdResponse
fn new_empty() -> QrtrClientConnectionGetPortIdResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<QrtrClientConnectionGetPortIdResponse, D> for &QrtrClientConnectionGetPortIdResponsewhere
D: ResourceDialect,
impl<D> Encode<QrtrClientConnectionGetPortIdResponse, D> for &QrtrClientConnectionGetPortIdResponsewhere
D: ResourceDialect,
Sourceimpl Ord for QrtrClientConnectionGetPortIdResponse
impl Ord for QrtrClientConnectionGetPortIdResponse
Sourcefn cmp(&self, other: &QrtrClientConnectionGetPortIdResponse) -> Ordering
fn cmp(&self, other: &QrtrClientConnectionGetPortIdResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QrtrClientConnectionGetPortIdResponse
impl PartialEq for QrtrClientConnectionGetPortIdResponse
Sourcefn eq(&self, other: &QrtrClientConnectionGetPortIdResponse) -> bool
fn eq(&self, other: &QrtrClientConnectionGetPortIdResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for QrtrClientConnectionGetPortIdResponse
impl PartialOrd for QrtrClientConnectionGetPortIdResponse
Sourceimpl TypeMarker for QrtrClientConnectionGetPortIdResponse
impl TypeMarker for QrtrClientConnectionGetPortIdResponse
Sourcetype Owned = QrtrClientConnectionGetPortIdResponse
type Owned = QrtrClientConnectionGetPortIdResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for QrtrClientConnectionGetPortIdResponse
impl ValueTypeMarker for QrtrClientConnectionGetPortIdResponse
Sourcetype Borrowed<'a> = &'a QrtrClientConnectionGetPortIdResponse
type Borrowed<'a> = &'a QrtrClientConnectionGetPortIdResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<QrtrClientConnectionGetPortIdResponse as TypeMarker>::Owned,
) -> <QrtrClientConnectionGetPortIdResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<QrtrClientConnectionGetPortIdResponse as TypeMarker>::Owned, ) -> <QrtrClientConnectionGetPortIdResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for QrtrClientConnectionGetPortIdResponse
impl Eq for QrtrClientConnectionGetPortIdResponse
impl Persistable for QrtrClientConnectionGetPortIdResponse
impl StructuralPartialEq for QrtrClientConnectionGetPortIdResponse