pub struct QrtrClientConnectionMarker;Trait Implementations
Sourceimpl Clone for QrtrClientConnectionMarker
impl Clone for QrtrClientConnectionMarker
Sourcefn clone(&self) -> QrtrClientConnectionMarker
fn clone(&self) -> QrtrClientConnectionMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QrtrClientConnectionMarker
impl Debug for QrtrClientConnectionMarker
Sourceimpl Hash for QrtrClientConnectionMarker
impl Hash for QrtrClientConnectionMarker
Sourceimpl Ord for QrtrClientConnectionMarker
impl Ord for QrtrClientConnectionMarker
Sourcefn cmp(&self, other: &QrtrClientConnectionMarker) -> Ordering
fn cmp(&self, other: &QrtrClientConnectionMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for QrtrClientConnectionMarker
impl PartialOrd for QrtrClientConnectionMarker
Sourceimpl ProtocolMarker for QrtrClientConnectionMarker
impl ProtocolMarker for QrtrClientConnectionMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) QrtrClientConnection"
const DEBUG_NAME: &'static str = "(anonymous) QrtrClientConnection"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = QrtrClientConnectionProxy
type Proxy = QrtrClientConnectionProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = QrtrClientConnectionRequestStream
type RequestStream = QrtrClientConnectionRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = QrtrClientConnectionSynchronousProxy
type SynchronousProxy = QrtrClientConnectionSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for QrtrClientConnectionMarker
impl Eq for QrtrClientConnectionMarker
impl StructuralPartialEq for QrtrClientConnectionMarker