pub struct QrtrClientConnectionProxy { /* private fields */ }Implementations
Sourceimpl QrtrClientConnectionProxy
impl QrtrClientConnectionProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.qualcomm.router/QrtrClientConnection.
Sourcepub fn take_event_stream(&self) -> QrtrClientConnectionEventStream
pub fn take_event_stream(&self) -> QrtrClientConnectionEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn read(
&self,
) -> QueryResponseFut<QrtrClientConnectionReadResult, DefaultFuchsiaResourceDialect>
pub fn read( &self, ) -> QueryResponseFut<QrtrClientConnectionReadResult, DefaultFuchsiaResourceDialect>
Reads a QRTR frame via the connection.
Only one read request can be performed at a time.
src_node_id: Source node ID of the QRTR frame.src_port: Source port of the QRTR frame.data: QRTR payload.
- Errors:
WOULD_BLOCK: Cannot read; should wait in non-blocking mode.ALREADY_PENDING: More than one read operation is pending in blocking mode.INTERNAL_ERROR: Unexpected QRTR error.
Sourcepub fn write(
&self,
dst_node_id: u32,
dst_port: u32,
data: &[u8],
) -> QueryResponseFut<QrtrClientConnectionWriteResult, DefaultFuchsiaResourceDialect>
pub fn write( &self, dst_node_id: u32, dst_port: u32, data: &[u8], ) -> QueryResponseFut<QrtrClientConnectionWriteResult, DefaultFuchsiaResourceDialect>
Writes a QRTR frame.
Only one write request can be performed at a time.
- Errors:
WOULD_BLOCK: Cannot write; should wait in non-blocking mode.ALREADY_PENDING: More than one write operation is pending in blocking mode.REMOTE_NODE_UNAVAILABLE: Target node unavailable.INTERNAL_ERROR: Unexpected QRTR error.
Sourcepub fn get_signals(
&self,
) -> QueryResponseFut<EventPair, DefaultFuchsiaResourceDialect>
pub fn get_signals( &self, ) -> QueryResponseFut<EventPair, DefaultFuchsiaResourceDialect>
Retrieves the signals eventpair.
- response
signalsan eventpair that is signalled withSIGNAL_READABLEandSIGNAL_WRITABLEwhen read and write buffers are available, respectively.
Sourcepub fn get_port_id(
&self,
) -> QueryResponseFut<u32, DefaultFuchsiaResourceDialect>
pub fn get_port_id( &self, ) -> QueryResponseFut<u32, DefaultFuchsiaResourceDialect>
Retrieves the port id.
Sourcepub fn get_node_id(
&self,
) -> QueryResponseFut<u32, DefaultFuchsiaResourceDialect>
pub fn get_node_id( &self, ) -> QueryResponseFut<u32, DefaultFuchsiaResourceDialect>
Retrieves the node id of AP.
Sourcepub fn close_connection(
&self,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn close_connection( &self, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Close the connection.
Server end drops its end of the channel after replying. This can be used for synchronous resource release.