pub struct QrtrConnectorGetConnectionRequest {
pub options: ConnectionOptions,
pub proxy: ServerEnd<QrtrClientConnectionMarker>,
}Fields
options: ConnectionOptionsproxy: ServerEnd<QrtrClientConnectionMarker>Trait Implementations
Sourceimpl Decode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for QrtrConnectorGetConnectionRequest
impl Decode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for QrtrConnectorGetConnectionRequest
Sourceimpl Encode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for &mut QrtrConnectorGetConnectionRequest
impl Encode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for &mut QrtrConnectorGetConnectionRequest
Sourceimpl<T0: Encode<ConnectionOptions, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<QrtrClientConnectionMarker>>, DefaultFuchsiaResourceDialect>> Encode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<ConnectionOptions, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<QrtrClientConnectionMarker>>, DefaultFuchsiaResourceDialect>> Encode<QrtrConnectorGetConnectionRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl PartialEq for QrtrConnectorGetConnectionRequest
impl PartialEq for QrtrConnectorGetConnectionRequest
Sourcefn eq(&self, other: &QrtrConnectorGetConnectionRequest) -> bool
fn eq(&self, other: &QrtrConnectorGetConnectionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for QrtrConnectorGetConnectionRequest
impl ResourceTypeMarker for QrtrConnectorGetConnectionRequest
Sourcetype Borrowed<'a> = &'a mut QrtrConnectorGetConnectionRequest
type Borrowed<'a> = &'a mut QrtrConnectorGetConnectionRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for QrtrConnectorGetConnectionRequest
impl TypeMarker for QrtrConnectorGetConnectionRequest
Sourcetype Owned = QrtrConnectorGetConnectionRequest
type Owned = QrtrConnectorGetConnectionRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for QrtrConnectorGetConnectionRequest
impl StructuralPartialEq for QrtrConnectorGetConnectionRequest