pub struct QrtrConnectorMarker;Trait Implementations
Sourceimpl Clone for QrtrConnectorMarker
impl Clone for QrtrConnectorMarker
Sourcefn clone(&self) -> QrtrConnectorMarker
fn clone(&self) -> QrtrConnectorMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QrtrConnectorMarker
impl Debug for QrtrConnectorMarker
Sourceimpl DiscoverableProtocolMarker for QrtrConnectorMarker
impl DiscoverableProtocolMarker for QrtrConnectorMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for QrtrConnectorMarker
impl Hash for QrtrConnectorMarker
Sourceimpl Ord for QrtrConnectorMarker
impl Ord for QrtrConnectorMarker
Sourcefn cmp(&self, other: &QrtrConnectorMarker) -> Ordering
fn cmp(&self, other: &QrtrConnectorMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QrtrConnectorMarker
impl PartialEq for QrtrConnectorMarker
Sourceimpl PartialOrd for QrtrConnectorMarker
impl PartialOrd for QrtrConnectorMarker
Sourceimpl ProtocolMarker for QrtrConnectorMarker
impl ProtocolMarker for QrtrConnectorMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.hardware.qualcomm.router.QrtrConnector"
const DEBUG_NAME: &'static str = "fuchsia.hardware.qualcomm.router.QrtrConnector"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = QrtrConnectorProxy
type Proxy = QrtrConnectorProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = QrtrConnectorRequestStream
type RequestStream = QrtrConnectorRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = QrtrConnectorSynchronousProxy
type SynchronousProxy = QrtrConnectorSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for QrtrConnectorMarker
impl Eq for QrtrConnectorMarker
impl StructuralPartialEq for QrtrConnectorMarker