pub struct QrtrConnectorProxy { /* private fields */ }Implementations
Sourceimpl QrtrConnectorProxy
impl QrtrConnectorProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.qualcomm.router/QrtrConnector.
Sourcepub fn take_event_stream(&self) -> QrtrConnectorEventStream
pub fn take_event_stream(&self) -> QrtrConnectorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_connection(
&self,
options: &ConnectionOptions,
proxy: ServerEnd<QrtrClientConnectionMarker>,
) -> QueryResponseFut<QrtrConnectorGetConnectionResult, DefaultFuchsiaResourceDialect>
pub fn get_connection( &self, options: &ConnectionOptions, proxy: ServerEnd<QrtrClientConnectionMarker>, ) -> QueryResponseFut<QrtrConnectorGetConnectionResult, DefaultFuchsiaResourceDialect>
Gets a new connection from QRTR.
If port is specificed in options, creates a connection with target
port. Otherwise, assigns a random port for the connection.
- Errors:
INTERNAL_ERROR: Unexpected QRTR error.INVALID_ARGS: Invalid arguments inConnectionOptions.NO_RESOURCES: No non-reserved port available.ALREADY_BOUND: Specified port inConnectionOptionsis in use.