pub struct QrtrConnectorSynchronousProxy { /* private fields */ }Implementations
Sourceimpl QrtrConnectorSynchronousProxy
impl QrtrConnectorSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<QrtrConnectorEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<QrtrConnectorEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_connection(
&self,
options: &ConnectionOptions,
proxy: ServerEnd<QrtrClientConnectionMarker>,
___deadline: MonotonicInstant,
) -> Result<QrtrConnectorGetConnectionResult, Error>
pub fn get_connection( &self, options: &ConnectionOptions, proxy: ServerEnd<QrtrClientConnectionMarker>, ___deadline: MonotonicInstant, ) -> Result<QrtrConnectorGetConnectionResult, Error>
Gets a new connection from QRTR.
If port is specificed in options, creates a connection with target
port. Otherwise, assigns a random port for the connection.
- Errors:
INTERNAL_ERROR: Unexpected QRTR error.INVALID_ARGS: Invalid arguments inConnectionOptions.NO_RESOURCES: No non-reserved port available.ALREADY_BOUND: Specified port inConnectionOptionsis in use.