pub struct QrtrTransportChannelMarker;Trait Implementations
Sourceimpl Clone for QrtrTransportChannelMarker
impl Clone for QrtrTransportChannelMarker
Sourcefn clone(&self) -> QrtrTransportChannelMarker
fn clone(&self) -> QrtrTransportChannelMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QrtrTransportChannelMarker
impl Debug for QrtrTransportChannelMarker
Sourceimpl Hash for QrtrTransportChannelMarker
impl Hash for QrtrTransportChannelMarker
Sourceimpl Ord for QrtrTransportChannelMarker
impl Ord for QrtrTransportChannelMarker
Sourcefn cmp(&self, other: &QrtrTransportChannelMarker) -> Ordering
fn cmp(&self, other: &QrtrTransportChannelMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for QrtrTransportChannelMarker
impl PartialOrd for QrtrTransportChannelMarker
Sourceimpl ProtocolMarker for QrtrTransportChannelMarker
impl ProtocolMarker for QrtrTransportChannelMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) QrtrTransportChannel"
const DEBUG_NAME: &'static str = "(anonymous) QrtrTransportChannel"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = QrtrTransportChannelProxy
type Proxy = QrtrTransportChannelProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = QrtrTransportChannelRequestStream
type RequestStream = QrtrTransportChannelRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = QrtrTransportChannelSynchronousProxy
type SynchronousProxy = QrtrTransportChannelSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for QrtrTransportChannelMarker
impl Eq for QrtrTransportChannelMarker
impl StructuralPartialEq for QrtrTransportChannelMarker