pub struct QrtrTransportChannelProxy { /* private fields */ }Implementations
Sourceimpl QrtrTransportChannelProxy
impl QrtrTransportChannelProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.qualcomm.router/QrtrTransportChannel.
Sourcepub fn take_event_stream(&self) -> QrtrTransportChannelEventStream
pub fn take_event_stream(&self) -> QrtrTransportChannelEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn read(
&self,
) -> QueryResponseFut<QrtrTransportChannelReadResult, DefaultFuchsiaResourceDialect>
pub fn read( &self, ) -> QueryResponseFut<QrtrTransportChannelReadResult, DefaultFuchsiaResourceDialect>
Reads a QRTR frame from a transport driver.
Blocks until an inbound frame is ready to be consumed. Only one read request can be performed at a time.
data: QRTR frame.
- Errors:
ALREADY_PENDING: More than one read operation is pending.INTERNAL_ERROR: Unexpected QRTR error.
Sourcepub fn write(
&self,
data: &[u8],
) -> QueryResponseFut<QrtrTransportChannelWriteResult, DefaultFuchsiaResourceDialect>
pub fn write( &self, data: &[u8], ) -> QueryResponseFut<QrtrTransportChannelWriteResult, DefaultFuchsiaResourceDialect>
Writes a QRTR frame to a transport driver.
Only one write request can be performed at a time.
- Errors:
ALREADY_PENDING: More than one write operation is pending.INTERNAL_ERROR: Unexpected QRTR error.