pub struct QrtrTransportChannelSynchronousProxy { /* private fields */ }Implementations
Sourceimpl QrtrTransportChannelSynchronousProxy
impl QrtrTransportChannelSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<QrtrTransportChannelEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<QrtrTransportChannelEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn read(
&self,
___deadline: MonotonicInstant,
) -> Result<QrtrTransportChannelReadResult, Error>
pub fn read( &self, ___deadline: MonotonicInstant, ) -> Result<QrtrTransportChannelReadResult, Error>
Reads a QRTR frame from a transport driver.
Blocks until an inbound frame is ready to be consumed. Only one read request can be performed at a time.
data: QRTR frame.
- Errors:
ALREADY_PENDING: More than one read operation is pending.INTERNAL_ERROR: Unexpected QRTR error.
Sourcepub fn write(
&self,
data: &[u8],
___deadline: MonotonicInstant,
) -> Result<QrtrTransportChannelWriteResult, Error>
pub fn write( &self, data: &[u8], ___deadline: MonotonicInstant, ) -> Result<QrtrTransportChannelWriteResult, Error>
Writes a QRTR frame to a transport driver.
Only one write request can be performed at a time.
- Errors:
ALREADY_PENDING: More than one write operation is pending.INTERNAL_ERROR: Unexpected QRTR error.