pub struct QrtrTransportConnectorEstablishConnectionRequest {
pub options: TransportConnectionOptions,
pub proxy: ClientEnd<QrtrTransportChannelMarker>,
}Fields
options: TransportConnectionOptionsproxy: ClientEnd<QrtrTransportChannelMarker>Trait Implementations
Sourceimpl Decode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for QrtrTransportConnectorEstablishConnectionRequest
impl Decode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for QrtrTransportConnectorEstablishConnectionRequest
Sourceimpl Encode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for &mut QrtrTransportConnectorEstablishConnectionRequest
impl Encode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for &mut QrtrTransportConnectorEstablishConnectionRequest
Sourceimpl<T0: Encode<TransportConnectionOptions, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ClientEnd<QrtrTransportChannelMarker>>, DefaultFuchsiaResourceDialect>> Encode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<TransportConnectionOptions, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ClientEnd<QrtrTransportChannelMarker>>, DefaultFuchsiaResourceDialect>> Encode<QrtrTransportConnectorEstablishConnectionRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl PartialEq for QrtrTransportConnectorEstablishConnectionRequest
impl PartialEq for QrtrTransportConnectorEstablishConnectionRequest
Sourcefn eq(&self, other: &QrtrTransportConnectorEstablishConnectionRequest) -> bool
fn eq(&self, other: &QrtrTransportConnectorEstablishConnectionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for QrtrTransportConnectorEstablishConnectionRequest
impl ResourceTypeMarker for QrtrTransportConnectorEstablishConnectionRequest
Sourcetype Borrowed<'a> = &'a mut QrtrTransportConnectorEstablishConnectionRequest
type Borrowed<'a> = &'a mut QrtrTransportConnectorEstablishConnectionRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for QrtrTransportConnectorEstablishConnectionRequest
impl TypeMarker for QrtrTransportConnectorEstablishConnectionRequest
Sourcetype Owned = QrtrTransportConnectorEstablishConnectionRequest
type Owned = QrtrTransportConnectorEstablishConnectionRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for QrtrTransportConnectorEstablishConnectionRequest
impl StructuralPartialEq for QrtrTransportConnectorEstablishConnectionRequest