pub struct QrtrTransportConnectorProxy { /* private fields */ }Implementations
Sourceimpl QrtrTransportConnectorProxy
impl QrtrTransportConnectorProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.hardware.qualcomm.router/QrtrTransportConnector.
Sourcepub fn take_event_stream(&self) -> QrtrTransportConnectorEventStream
pub fn take_event_stream(&self) -> QrtrTransportConnectorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn establish_connection(
&self,
options: &TransportConnectionOptions,
proxy: ClientEnd<QrtrTransportChannelMarker>,
) -> QueryResponseFut<QrtrTransportConnectorEstablishConnectionResult, DefaultFuchsiaResourceDialect>
pub fn establish_connection( &self, options: &TransportConnectionOptions, proxy: ClientEnd<QrtrTransportChannelMarker>, ) -> QueryResponseFut<QrtrTransportConnectorEstablishConnectionResult, DefaultFuchsiaResourceDialect>
Establishes a channel.
Child drivers should only establish one connection to the QRTR driver.