pub struct QrtrTransportConnectorSynchronousProxy { /* private fields */ }Implementations
Sourceimpl QrtrTransportConnectorSynchronousProxy
impl QrtrTransportConnectorSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<QrtrTransportConnectorEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<QrtrTransportConnectorEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn establish_connection(
&self,
options: &TransportConnectionOptions,
proxy: ClientEnd<QrtrTransportChannelMarker>,
___deadline: MonotonicInstant,
) -> Result<QrtrTransportConnectorEstablishConnectionResult, Error>
pub fn establish_connection( &self, options: &TransportConnectionOptions, proxy: ClientEnd<QrtrTransportChannelMarker>, ___deadline: MonotonicInstant, ) -> Result<QrtrTransportConnectorEstablishConnectionResult, Error>
Establishes a channel.
Child drivers should only establish one connection to the QRTR driver.